@@ -28,6 +28,7 @@ Foundation; version 2 of the licence.
 #include "callbacks.h"
 #include "interface.h"
 #include "support.h"
+#include "completion.h"
 
 #define GLADE_HOOKUP_OBJECT(component,widget,name) \
     g_object_set_data_full (G_OBJECT (component), name, \
@@ -120,6 +121,7 @@ create_main (void)
     gtk_box_pack_start (GTK_BOX (vbox1), table2, FALSE, TRUE, 3);
 
     album_artist = gtk_entry_new ();
+    create_completion(album_artist, "album_artist");
     gtk_widget_show (album_artist);
     gtk_table_attach (GTK_TABLE (table2), album_artist, 1, 2, 1, 2,
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -127,6 +129,7 @@ create_main (void)
 
     album_title = gtk_entry_new ();
     gtk_widget_show (album_title);
+    create_completion(album_title, "album_title");
     gtk_table_attach (GTK_TABLE (table2), album_title, 1, 2, 2, 3,
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
@@ -137,6 +140,7 @@ create_main (void)
                       (GtkAttachOptions) (GTK_FILL), 0, 0);
 
     album_genre = gtk_entry_new();						// lnr
+    create_completion(album_genre, "album_genre");
     gtk_widget_show( album_genre );
     gtk_table_attach( GTK_TABLE( table2 ), album_genre, 1, 2, 3, 4,
                       (GtkAttachOptions) ( GTK_EXPAND | GTK_FILL ),
@@ -451,8 +455,18 @@ create_prefs (void)
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
-    gtk_misc_set_padding (GTK_MISC (label), 0, 7);
-
+    
+    label = gtk_label_new (_("%G - Genre"));
+    gtk_widget_show (label);
+    gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
+    
+    // problem is that the same albumdir is used (threads.c) for all formats
+    //~ label = gtk_label_new (_("%F - Format (e.g. FLAC)"));
+    //~ gtk_widget_show (label);
+    //~ gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+    //~ gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
+    
     table1 = gtk_table_new (3, 2, FALSE);
     gtk_widget_show (table1);
     gtk_box_pack_start (GTK_BOX (vbox), table1, TRUE, TRUE, 0);
@@ -1335,7 +1349,7 @@ void enable_musepack_widgets(void)
 
 #if GTK_MINOR_VERSION >= 6
 static const char* 
-GBLprogramName = "Asunder 2.1";
+GBLprogramName = "Asunder 2.2";
 
 static const char* 
 GBLauthors[2] = {
@@ -1369,6 +1383,12 @@ GBLauthors[2] = {
 "Cyril Brulebois\n"
 "- A kFreeBSD fix.\n"
 "\n"
+"Richard Gill\n"
+"- Support for XDG_CONFIG_HOME.\n"
+"\n"
+"Hiroyuki Ito\n"
+"- Support for autocompletion in artist/album/genre fields.\n"
+"\n"
 "Packages:\n"
 "\n"
 "Toni Graffy\n"
@@ -1440,6 +1460,9 @@ GBLtranslators =
 "Emil Krumov\n"
 "- bg (Bulgarian) translation of Asunder versions 1.0.2 - 1.9\n"
 "\n"
+"Davor Buday\n"
+"- bs_BA (Bosnian / Bosnia and Herzegovina) translation of Asunder version 2.1\n"
+"\n"
 "Siegfried-Angel Gevatter Pujals\n"
 "- ca (Catalan) translation of Asunder versions 0.8.1 - 1.9\n"
 "\n"
@@ -1460,7 +1483,10 @@ GBLtranslators =
 "\n"
 "George Vlahavas\n"
 "- el (Greek) translation of Asunder version 1.5\n"
-"\n"   
+"\n"
+"Formiko\n"
+"- eo (Esperanto) translation of Asunder version 2.1\n"
+"\n"
 "Juan Garcia-Murga Monago\n"
 "- es (Spanish) translation of Asunder versions 0.8 - 1.9\n"
 "\n"
@@ -1497,6 +1523,9 @@ GBLtranslators =
 "UTUMI Hirosi\n"
 "- ja (Japanese) translation of Asunder versions 1.0 - 1.5\n"
 "\n"
+"Hiroyuki Ito\n"
+"- ja (Japanese) translation of Asunder version 2.1\n"
+"\n"
 "Kristaps Kulis\n"
 "- lv (Latvian) translation of Asunder version 1.6\n"
 "\n"
@@ -1529,7 +1558,10 @@ GBLtranslators =
 "\n"
 "Sergio Brandao Cipolla\n"
 "- pt_BR (Portuguese/Brazil) translation of Asunder version 1.9.1\n"
-"\n"       
+"\n"
+"Pedro Henrique\n"
+"- pt_BR (Portuguese/Brazil) translation of Asunder version 2.1\n"
+"\n"
 "Alexandre Prokoudine\n"
 "- ru (Russian) translation of Asunder version 1.9.2\n"
 "\n"
@@ -1543,7 +1575,7 @@ GBLtranslators =
 "- sk (Slovak) translation of Asunder version 1.6.3\n"
 "\n"
 "Uros Golob\n"
-"- sl (Slovenian) translation of Asunder version 1.9\n"
+"- sl (Slovenian) translation of Asunder versions 1.9 - 2.1\n"
 "\n"
 "Besnik Bleta\n"
 "- sq (Albanian) translation of Asunder versions 0.8 - 1.9\n"
@@ -1577,7 +1609,7 @@ N_("An application to save tracks from an Audio CD \n"
 static const char* 
 GBLcopyright = 
 "Copyright 2005 Eric Lathrop\n"
-"Copyright 2007 - 2010 Andrew Smith";
+"Copyright 2007 - 2012 Andrew Smith";
 
 static const char* 
 GBLwebsite = "http://littlesvr.ca/asunder/";
