@@ -2,14 +2,19 @@
 #include <cddb/cddb.h>
 #include <stdbool.h>
 
+#define LOG_FILE "/tmp/asunder.log"
+
+// LNR - I think the editable genre column should come before the static track time,
+// but it could arguably come between artist and title so the two editable columns
+// would be together. 
 enum
 {
     COL_RIPTRACK,
     COL_TRACKNUM,
     COL_TRACKARTIST,
     COL_TRACKTITLE,
-    COL_TRACKTIME,
     COL_GENRE,
+    COL_TRACKTIME,
     COL_YEAR,
     NUM_COLS
 };
@@ -41,7 +46,7 @@ void refresh(char * cdrom, int force);
 // updates all the necessary widgets with the data for the given cddb_disc_t
 void update_tracklist(cddb_disc_t * disc);
 
-extern GList * disc_matches;
+extern GList * gbl_disc_matches;
 
 extern GtkWidget * win_main;
 extern GtkWidget * win_prefs;
