@@ -21,7 +21,8 @@ int int_to_musepack_int(int i);
 // title - gets substituted for %T in format
 //
 // NOTE: caller must free the returned string!
-char * parse_format(const char * format, int tracknum, const char * year, const char * artist, const char * album, const char * title);
+char * parse_format(const char* format, int tracknum, const char* year, const char* artist, 
+                    const char* album, const char* genre, const char* title);
 
 // construct a filename from various parts
 //
